embassy-net

Crates

git

Versions

default

Flavors

DhcpLease

Struct DhcpLease 

pub struct DhcpLease {
    pub server: DhcpServerInfo,
    pub address: Cidr,
    pub router: Option<Ipv4Addr>,
    pub dns_servers: VecInner<Ipv4Addr, usize, VecStorageInner<[MaybeUninit<Ipv4Addr>; 3]>>,
    pub options: DhcpLeaseOptions,
}
A lease obtained from a DHCP server.

Fields

server: DhcpServerInfo

How to reach the server that gave the lease.

address: Cidr

The leased address and its subnet.

router: Option<Ipv4Addr>

The default gateway, if the server gave one.

dns_servers: VecInner<Ipv4Addr, usize, VecStorageInner<[MaybeUninit<Ipv4Addr>; 3]>>

The DNS servers, if the server gave any.

options: DhcpLeaseOptions

All options received from the DHCP server.

You may have to ask the server to send the option you’re interested in with [DhcpConfig::parameter_request_list].